@@ -209,6 +209,15 @@ class Device(Events):
     def file_exist(self, file_path):
         return bool(int(str(self.con.get(path="checkFileExist", args="filename=" + file_path).read(), 'utf-8')))
 
+    def file_remove(self, file_path):
+        return bool(int(str(self.con.get(path="fileRemove", args="filename=" + file_path).read(), 'utf-8')))
+
+    def file_move(self, source_path, target_path):
+        return bool(int(str(self.con.get(path="fileMove", args="source=" + source_path + "&target=" + target_path).read(), 'utf-8')))
+
+    def file_copy(self, source_path, target_path):
+        return bool(int(str(self.con.get(path="fileCopy", args="source=" + source_path + "&target=" + target_path).read(), 'utf-8')))
+
     def dir_exist(self, dir_path):
         return self.file_exist(dir_path)
 
@@ -232,7 +241,7 @@ class Device(Events):
         return bool(int(str(self.con.get(path="uninstall", args="sopid=" + sopid).read(), 'utf-8')))
 
     def system_time(self):
-        return int(str(self.con.get(path="uninstall").read(), 'utf-8'))
+        return int(str(self.con.get(path="getDatetime").read(), 'utf-8'))
 
     def log(self, level, text):
         pass
