@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
+import urllib.parse
 from time import sleep
 from lxml import etree
 
@@ -88,7 +88,7 @@ class Events:
         return "unknown"
 
     def submit_string(self, text):
-        return self.__reply_status_check(self.device.con.get(path="sendCommitString", args="str=" + text))
+        return self.__reply_status_check(self.device.con.get(path="sendCommitString", args="str=" + urllib.parse.quote(text)))
 
     def click(self, x, y):
         return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + str(x) + "|" + str(y)))
